@@ -4,7 +4,7 @@ use warnings;
 
 use version;
 
-our $VERSION = '1.04';
+our $VERSION = '2.00';
 
 my $log;
 
@@ -17,18 +17,34 @@ sub new {
     $log = $self->{log};
     $log->_6("constructing new Test::BrewBuild::BrewCommands object");
 
+    $self->brew;
+
     return $self;
 }
 sub brew {
     my $self = shift;
-    my $brew = $self->is_win ? 'berrybrew' : 'perlbrew';
+
+    return $self->{brew} if $self->{brew};
+
+    my $brew;
+
+    if ($self->is_win){
+        my $exe_loc = `where berrybrew.exe`;
+        $brew = (split /\n/, $exe_loc)[0];
+    }
+    else {
+        $brew = 'perlbrew';
+    }
+
     $log->child('brew')->_6("*brew cmd is: $brew");
+    $self->{brew} = $brew;
+
     return $brew;
 }
 sub info {
     my $self = shift;
     return $self->is_win
-        ? `berrybrew available 2>nul`
+        ? `$self->{brew} available 2>nul`
         : `perlbrew available 2>/dev/null`;
 }
 sub installed {
@@ -83,7 +99,7 @@ sub install {
     my $self = shift;
 
     my $install_cmd = $self->is_win
-        ? 'berrybrew install'
+        ? "$self->{brew} install"
         : 'perlbrew install --notest -j 4';
 
     $log->child('install')->_6("install cmd is: $install_cmd");
@@ -94,7 +110,7 @@ sub remove {
     my $self = shift;
 
     my $remove_cmd = $self->is_win
-        ? 'berrybrew remove'
+        ? "$self->{brew} remove"
         : 'perlbrew uninstall';
 
     $log->child('remove')->_6("remove cmd is: $remove_cmd");
@@ -111,7 +127,7 @@ sub is_win {
 =head1 NAME
 
 Test::BrewBuild::BrewCommands - Provides Windows/Unix *brew command
-translations.
+translations for Test::BrewBuild
 
 =head1 METHODS
 
@@ -121,32 +137,35 @@ Returns a new Test::BrewBuild::BrewCommands object.
 
 =head2 brew
 
-Returns 'perlbrew' if on Unix, and 'berrybrew' if on Windows.
+Returns C<perlbrew> if on Unix, and the full executable path for
+C<berrybrew.exe> if on Windows.
 
 =head2 info
 
-Returns the string result of *brew available.
+Returns the string result of C<*brew available>.
 
 =head2 installed($info)
 
-Takes the output of '*brew available' in a string form. Returns the currently
+Takes the output of C<*brew available> in a string form. Returns the currently
 installed versions, formatted in a platform specific manner.
 
-=head2 available($legacy, $info)
-
-Similar to C<installed()>, but returns all perls available.
-
 =head2 using($info)
 
-Returns the current version of perl we're using.
+Returns the current version of perl we're using. C<$info> is the output from
+C<info()>.
+
+=head2 available($legacy, $info)
+
+Similar to C<installed()>, but returns all perls available. If C<$legacy> is
+false, we'll only return C<perl> versions C<5.8.0+>.
 
 =head2 install
 
-Returns the current OS's specific *brew install command.
+Returns the current OS's specific C<*brew install> command.
 
 =head2 remove
 
-Returns the current OS's specific *brew remove command.
+Returns the current OS's specific C<*brew remove> command.
 
 =head2 is_win
 
