@@ -12,7 +12,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '1.05_02';
+our $VERSION = '2.00';
 
 $| = 1;
 
@@ -76,19 +76,91 @@ sub dispatch {
 
     # spin up the comms
 
+    %remotes = $self->_fork(\%remotes, $cmd, $repo);
+
+    if (! -d 'bblog'){
+        mkdir 'bblog' or die $!;
+        $log->_7("created log dir: bblog");
+    }
+
+    # init the return string
+
+    my $return = "\n";
+
+    for my $ip (keys %remotes){
+        if (! defined $remotes{$ip}{build}){
+            $log->_5("tester: $ip didn't supply results... deleting");
+            delete $remotes{$ip};
+            next;
+        }
+
+        # build log file generation
+
+        for my $build_log (keys %{ $remotes{$ip}{build}{files} }){
+            $log->_7("generating build log: $build_log");
+
+            my $content = $remotes{$ip}{build}{files}{$build_log};
+            $log->_7("writing out log: " . getcwd() . "/bblog/$ip\_$build_log");
+            open my $wfh, '>', "bblog/$ip\_$build_log" or die $!;
+            for (@$content){
+                print $wfh $_;
+            }
+        }
+
+        # build the return string
+
+        my $build = $remotes{$ip}{build};
+
+        $return .= "$ip - $build->{platform}\n";
+        $return .= "$build->{log}" if $build->{log};
+
+        if (ref $build->{data} eq 'ARRAY'){
+            $return .= $_ for @{ $build->{data} };
+        }
+        else {
+            $return .= "$build->{data}\n";
+        }
+    }
+    $log->_7("returning results...");
+    return $return;
+}
+sub _config {
+    # slurp in config file elements
+
+    my $self = shift;
+
+     my $conf_file = Test::BrewBuild->config_file;
+
+    if (-f $conf_file){
+        my $conf = Config::Tiny->read($conf_file)->{dispatch};
+        if ($conf->{testers}){
+            $conf->{testers} =~ s/\s+//;
+            $self->{testers} = [ split /,/, $conf->{testers} ];
+        }
+        $self->{repo} = $conf->{repo} if $conf->{repo};
+        $self->{cmd} = $conf->{cmd} if $conf->{cmd};
+    }
+}
+sub _fork {
+    # handles the tester communications
+
+    my ($self, $remotes, $cmd, $repo) = @_;
+
+    my $log = $log->child('_fork');
+
     my $pm = Parallel::ForkManager->new($self->{forks});
 
     $pm->run_on_finish(
         sub {
             my (undef, undef, undef, undef, undef, $tester_data) = @_;
-            map {$remotes{$_} = $tester_data->{$_}} keys %$tester_data;
+            map {$remotes->{$_} = $tester_data->{$_}} keys %$tester_data;
             $log->_5("tester: " . (keys %$tester_data)[0] ." finished")
               if keys %$tester_data;
         }
     );
 
     CLIENTS:
-    for my $tester (keys %remotes){
+    for my $tester (keys %$remotes){
         $log->_7("spinning up tester: $tester");
 
         $pm->start and next CLIENTS;
@@ -97,12 +169,12 @@ sub dispatch {
 
         my $socket = new IO::Socket::INET (
             PeerHost => $tester,
-            PeerPort => $remotes{$tester}{port},
+            PeerPort => $remotes->{$tester}{port},
             Proto => 'tcp',
         );
         if (! $socket){
             die "can't connect to remote $tester on port " .
-                "$remotes{$tester}{port} $!\n";
+                "$remotes->{$tester}{port} $!\n";
         }
 
         $log->_7("tester $tester socket created ok");
@@ -156,8 +228,8 @@ sub dispatch {
             $return{$tester}{build} = Storable::fd_retrieve($socket);
         }
         else {
-            $log->_5("deleted tester: $remotes{$tester}... incomplete session");
-            delete $remotes{$tester};
+            $log->_5("deleted tester: $remotes->{$tester}... incomplete session");
+            delete $remotes->{$tester};
         }
         $socket->close();
         $pm->finish(0, \%return);
@@ -165,68 +237,7 @@ sub dispatch {
 
     $pm->wait_all_children;
 
-    # process the results
-
-    if (! -d 'bblog'){
-        mkdir 'bblog' or die $!;
-        $log->_7("created log dir: bblog");
-    }
-
-    # init the return string
-
-    my $return = "\n";
-
-    for my $ip (keys %remotes){
-        if (! defined $remotes{$ip}{build}){
-            $log->_5("tester: $ip didn't supply results... deleting");
-            delete $remotes{$ip};
-            next;
-        }
-
-        # build log file generation
-
-        for my $build_log (keys %{ $remotes{$ip}{build}{files} }){
-            $log->_7("generating build log: $build_log");
-
-            my $content = $remotes{$ip}{build}{files}{$build_log};
-            $log->_7("writing out log: " . getcwd() . "/bblog/$ip\_$build_log");
-            open my $wfh, '>', "bblog/$ip\_$build_log" or die $!;
-            for (@$content){
-                print $wfh $_;
-            }
-        }
-
-        # build the return string
-
-        my $build = $remotes{$ip}{build};
-
-        $return .= "$ip - $build->{platform}\n";
-        $return .= "$build->{log}" if $build->{log};
-
-        if (ref $build->{data} eq 'ARRAY'){
-            $return .= $_ for @{ $build->{data} };
-        }
-        else {
-            $return .= "$build->{data}\n";
-        }
-    }
-    $log->_7("returning results...");
-    return $return;
-}
-sub _config {
-    my $self = shift;
-
-     my $conf_file = Test::BrewBuild->config_file;
-
-    if (-f $conf_file){
-        my $conf = Config::Tiny->read($conf_file)->{dispatch};
-        if ($conf->{testers}){
-            $conf->{testers} =~ s/\s+//;
-            $self->{testers} = [ split /,/, $conf->{testers} ];
-        }
-        $self->{repo} = $conf->{repo} if $conf->{repo};
-        $self->{cmd} = $conf->{cmd} if $conf->{cmd};
-    }
+    return %$remotes;
 }
 1;
 
@@ -242,6 +253,10 @@ This is the remote dispatching system of L<Test::BrewBuild>.
 It dispatches out test runs to L<Test::BrewBuild::Tester> remote test servers
 to perform, then processes the results returned from those testers.
 
+By default, we try to look up the repository information from your current
+working directory. If it can't be found, you must supply it on the command line
+or within the configuration file.
+
 =head1 METHODS
 
 =head2 new
