@@ -13,7 +13,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '1.05_02';
+our $VERSION = '2.00';
 
 $| = 1;
 
@@ -62,11 +62,10 @@ sub start {
         }
     }
 
-    my ($perl, @args, $work_dir);
+    my ($perl, @args);
+    my $work_dir = Test::BrewBuild->workdir;
 
     if ($^O =~ /MSWin/){
-        $work_dir = "$ENV{HOMEPATH}/brewbuild";
-
         $log->_6("on Windows, using work dir $work_dir");
 
         $perl = (split /\n/, `where perl.exe`)[0];
@@ -77,8 +76,6 @@ sub start {
         @args = ($t, '--fg');
     }
     else {
-        $work_dir = "$ENV{HOME}/brewbuild";
-
         $log->_6("on Unix, using work dir $work_dir");
 
         $perl = 'perl';
@@ -186,22 +183,11 @@ sub listen {
              "$self->{port}"
     );
 
-    my $work_dir;
-
-    if ($^O =~ /MSWin/){
-        $work_dir = "$ENV{HOMEPATH}/brewbuild";
-        mkdir $work_dir if ! -d $work_dir;
-        chdir $work_dir;
-        $log->_7("on Windows, work dir is: $work_dir");
-        $log->_7("chdir to work dir: ".getcwd());
-    }
-    else {
-        $work_dir = "$ENV{HOME}/brewbuild";
-        mkdir $work_dir if ! -d $work_dir;
-        chdir $work_dir;
-        $log->_7("on Windows, work dir is: $work_dir");
-        $log->_7("chdir to work dir: ".getcwd());
-    }
+    my $work_dir = Test::BrewBuild->workdir;
+    mkdir $work_dir if ! -d $work_dir;
+    chdir $work_dir;
+    $log->_7("work dir is: $work_dir");
+    $log->_7("chdir to work dir: ".getcwd());
 
     while (1){
 
@@ -255,9 +241,9 @@ sub listen {
             my $git = Test::BrewBuild::Git->new;
 
             if (-d $git->name($repo)){
-                $log->_7("repo '".$git->name($repo)."' exists, pulling");
                 chdir $git->name($repo) or die $!;
                 $log->_7("chdir to: ".getcwd());
+                $log->_7("repo '".$git->name($repo)."' exists, pulling");
                 $git->pull;
             }
             else {
@@ -266,32 +252,35 @@ sub listen {
                 chdir $git->name($repo);
                 $log->_7("chdir to: ".getcwd());
             }
-            {
-                my %opts = Test::BrewBuild->options(\@args);
-                my $opt_str;
-                for (keys %opts){
-                    $opt_str .= "$_ => $opts{$_}\n" if defined $opts{$_};
-                }
-                $log->_5("commencing test run with args: $opt_str") if $opt_str;
 
-                my $bb = Test::BrewBuild->new(%opts);
-                $bb->log()->file(\$self->{log}) if ! $self->{log_to_stdout};
-                $bb->instance_remove if $opts{remove};
-                $bb->instance_install($opts{install}) if $opts{install};
+            my %opts = Test::BrewBuild->options(\@args);
+            my $opt_str;
 
-                if ($opts{notest}){
-                    $log->_5("no tests run due to --notest flag set");
-                    $log->_5("storing and sending results back to dispatcher");
-                    $res->{log} = $self->{log};
-                    Storable::nstore_fd($res, $dispatch);
-                    next;
-                }
-                if ($opts{revdep}){
-                    $res->{data} = $bb->revdep(%opts);
-                }
-                else {
-                    $res->{data} = $bb->test;
-                }
+            for (keys %opts){
+                $opt_str .= "$_ => $opts{$_}\n" if defined $opts{$_};
+            }
+            $log->_5("commencing test run with args: $opt_str") if $opt_str;
+            $log->_5("commencing default brewbuild run with no args");
+
+            my $bb = Test::BrewBuild->new(%opts);
+            $bb->log()->file(\$self->{log}) if ! $self->{log_to_stdout};
+            $bb->instance_remove if $opts{remove};
+            $bb->instance_install($opts{install}) if $opts{install};
+
+            if ($opts{notest}){
+                $log->_5("no tests run due to --notest flag set");
+                $log->_5("storing and sending results back to dispatcher");
+                $res->{log} = $self->{log};
+                Storable::nstore_fd($res, $dispatch);
+                next;
+            }
+            if ($opts{revdep}){
+                $log->_6("revdep enabled");
+                $res->{data} = $bb->revdep(%opts);
+            }
+            else {
+                $log->_7("executing test()");
+                $res->{data} = $bb->test;
             }
 
             if (-d 'bblog'){
@@ -344,6 +333,8 @@ sub port {
     $self->{port} = $port;
 }
 sub _config {
+    # bring in config file elements
+
     my $self = shift;
 
     my $conf_file = Test::BrewBuild->config_file;
@@ -355,13 +346,10 @@ sub _config {
     }
 }
 sub _pid_file {
+    # fetch the PID file location
     my $self = shift;
-
     return $self->{pid_file} if defined $self->{pid_file};
-
-    $self->{pid_file} = $^O =~ /MSWin/
-        ? "$ENV{HOMEPATH}/brewbuild/brewbuild.pid"
-        : "$ENV{HOME}/brewbuild/brewbuild.pid";
+    $self->{pid_file} = Test::BrewBuild->workdir . '/brewbuild.pid';
 }
 1;
 
@@ -375,6 +363,8 @@ execution, for Windows & Unix.
 Builds and puts into the background a L<Test::BrewBuild> remote tester
 listening service.
 
+Note that by default, the working directory is C<~/brewbuild> on all platforms.
+
 =head1 METHODS
 
 =head2 new
